# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-06-07 21:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('countries', '0005_auto_20160607_1416'),
    ]

    operations = [
        migrations.AlterField(
            model_name='country',
            name='common_name',
            field=models.CharField(default='test', help_text=b'Common Country name', max_length=255, unique=True),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='country',
            name='name',
            field=models.CharField(blank=True, help_text=b'Official Country name (ISO Full name)', max_length=255, null=True),
        ),
    ]



from countries.models import Country
import pandas as pd
from django.utils.termcolors import colorize


def load_countries():
    df = pd.read_csv('https://raw.githubusercontent.com/Valuehorizon/valuehorizon-countries/master/data/data-2016-06-01.csv')
    df = df.fillna("")
    for indexvalue in df.index:

        # Getting raw data from csv
        code2 = df.ix[indexvalue]["Alpha-2 code"]
        code3 = df.ix[indexvalue]["Alpha-3 code"]
        full_name = df.ix[indexvalue]["Full name"]
        if full_name == "":
            full_name = None
        num_code = df.ix[indexvalue]["Numeric code"]
        remark1 = df.ix[indexvalue]["Remark part 1"]
        remark2 = df.ix[indexvalue]["Remark part 2"]
        remark3 = df.ix[indexvalue]["Remark part 3"]
        remarks = df.ix[indexvalue]["Remarks"]
        com_name = df.ix[indexvalue]["Common name"]
        territory = df.ix[indexvalue]["Territory name"]

        # Getting ISO Status
        iso_dict = dict((v, k) for k, v in dict(Country.ISO_STATUS_CHOICES).iteritems())
        iso_raw = df.ix[indexvalue]["Status"]
        iso_stat = iso_dict[iso_raw]

        if df.ix[indexvalue]["Independent"] == "Yes":
            independent = True
        else:
            independent = False

        try:
            # Update data for existing country
            code_check = Country.objects.get(symbol_alpha2_code=code2)
            print "Country Code Already Exists for %s..." % str(com_name)
            code_check.name = full_name
            code_check.symbol_alpha3_code = code3
            code_check.is_independent = independent
            code_check.numeric_code = num_code
            code_check.remark_1 = remark1
            code_check.remark_2 = remark2
            code_check.remark_3 = remark3
            code_check.territory_name = territory
            code_check.iso_status = iso_stat
            code_check.common_name = com_name
            code_check.save()
        except Country.DoesNotExist:
            # Country does not exist..Add new country data
            print colorize("New Country Code Found...Save it!!", fg="red")
            print 'Creating Line'
            country_data = Country(name=full_name,
                                   symbol_alpha2_code=code2,
                                   symbol_alpha3_code=code3,
                                   is_independent=independent,
                                   numeric_code=num_code,
                                   remark_1=remark1,
                                   remark_2=remark2,
                                   remark_3=remark3,
                                   territory_name=territory,
                                   iso_status=iso_stat,
                                   common_name=com_name
                                   )
            print 'Done Creating Line'
            country_data.save()
            print colorize('Done Saving Line', fg="red")



from django.contrib import admin
from countries.models import Country, City, Government, Region

class CountryAdmin(admin.ModelAdmin):
    search_fields = ["name",]
    list_display = ['common_name', 'name', 'symbol_alpha2_code', 'symbol_alpha3_code', 'iso_status']
    list_filter = ['iso_status']
admin.site.register(Country, CountryAdmin)

class CityAdmin(admin.ModelAdmin):
    search_fields = ["name",]
    list_display= ['name', 'country']
admin.site.register(City, CityAdmin)

class GovernmentAdmin(admin.ModelAdmin):
    search_fields = ["name",]
admin.site.register(Government, GovernmentAdmin)

class RegionAdmin(admin.ModelAdmin): 
    search_fields = ["name",]
    filter_horizontal = ('country',)
admin.site.register(Region, RegionAdmin)





# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('countries', '0003_auto_20150527_1928'),
    ]

    operations = [
        migrations.AddField(
            model_name='country',
            name='common_name',
            field=models.CharField(help_text=b'Common Country name', max_length=255, null=True, blank=True),
        ),
        migrations.AlterField(
            model_name='country',
            name='iso_status',
            field=models.CharField(default=b'UND', max_length=3, choices=[('EXR', 'Exceptionally reserved'), ('FRU', 'Formerly used'), ('INR', 'Indeterminately reserved'), ('OFF', 'Officially assigned'), ('TRR', 'Transitionally reserved'), ('UND', 'Unassigned')]),
        ),
        migrations.AlterField(
            model_name='country',
            name='name',
            field=models.CharField(help_text=b'Official Country name', unique=True, max_length=255),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-06-07 18:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('countries', '0004_auto_20150528_1248'),
    ]

    operations = [
        migrations.AddField(
            model_name='country',
            name='is_independent',
            field=models.BooleanField(default=True),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='country',
            name='numeric_code',
            field=models.PositiveSmallIntegerField(default=1),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='country',
            name='remark_1',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='country',
            name='remark_2',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='country',
            name='remark_3',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='country',
            name='territory_name',
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name='country',
            name='name',
            field=models.CharField(help_text=b'Official Country name (ISO Full name)', max_length=255, unique=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-06-07 23:08
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('countries', '0006_auto_20160607_1742'),
    ]

    operations = [
        migrations.AlterField(
            model_name='country',
            name='symbol_alpha3_code',
            field=models.CharField(default='AAA', help_text=b'ISO 3166-1 alpha-3 symbol', max_length=3, unique=True),
            preserve_default=False,
        ),
    ]
